"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = require("react-native-reanimated");

var _ViewGestureHandlerRootHOC = _interopRequireDefault(require("./ViewGestureHandlerRootHOC"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const SimpleImageView = _ref => {
  let {
    imageUri,
    bgColor
  } = _ref;
  const startX = (0, _reactNativeReanimated.useSharedValue)(0);
  const transX = (0, _reactNativeReanimated.useSharedValue)(0);
  const startY = (0, _reactNativeReanimated.useSharedValue)(0);
  const transY = (0, _reactNativeReanimated.useSharedValue)(0);
  const scaleXY = (0, _reactNativeReanimated.useSharedValue)(1);
  const savedScale = (0, _reactNativeReanimated.useSharedValue)(1);
  const rotation = (0, _reactNativeReanimated.useSharedValue)(0);
  const savedRotation = (0, _reactNativeReanimated.useSharedValue)(0);
  const transXYStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    return {
      transform: [{
        translateX: transX.value
      }, {
        translateY: transY.value
      }, {
        scale: scaleXY.value
      }, {
        rotateZ: `${rotation.value / Math.PI * 180}deg`
      }]
    };
  }, []);

  const scaleAnimation = () => {
    'worklet';

    (0, _reactNativeReanimated.cancelAnimation)(scaleXY);
    (0, _reactNativeReanimated.cancelAnimation)(startX);
    (0, _reactNativeReanimated.cancelAnimation)(startY);
    savedScale.value = 1;
    startX.value = 0;
    startY.value = 0;
    scaleXY.value = (0, _reactNativeReanimated.withSpring)(1);
    transX.value = (0, _reactNativeReanimated.withSpring)(0);
    transY.value = (0, _reactNativeReanimated.withSpring)(0);
    rotation.value = (0, _reactNativeReanimated.withSpring)(0);
    savedRotation.value = 0;
  };

  const panHandler = _reactNativeGestureHandler.Gesture.Pan().maxPointers(1).onStart(() => {
    transX.value = startX.value;
    transY.value = startY.value;
  }).onUpdate(event => {
    transX.value = event.translationX + startX.value;
    transY.value = event.translationY + startY.value;
  }).onEnd(() => {
    startX.value = transX.value;
    startY.value = transY.value;
  });

  const pinchHandler = _reactNativeGestureHandler.Gesture.Pinch().onUpdate(e => {
    scaleXY.value = savedScale.value * (e.scale > 0 ? e.scale : 1);
  }).onEnd(() => {
    savedScale.value = scaleXY.value > 0 ? scaleXY.value : 1;
  });

  const tapHandler = _reactNativeGestureHandler.Gesture.Tap().numberOfTaps(2).maxDelay(300).onEnd(scaleAnimation);

  const rotateHandler = _reactNativeGestureHandler.Gesture.Rotation().onUpdate(e => {
    rotation.value = savedRotation.value + e.rotation;
  }).onEnd(() => {
    savedRotation.value = rotation.value;
  });

  const simultaneousHandler = _reactNativeGestureHandler.Gesture.Simultaneous(panHandler, pinchHandler, tapHandler, rotateHandler);

  return imageUri !== null && imageUri !== void 0 && imageUri.uri ? /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.GestureDetector, {
    gesture: simultaneousHandler
  }, /*#__PURE__*/_react.default.createElement(_ViewGestureHandlerRootHOC.default, {
    imageUri: imageUri,
    transXYStyle: transXYStyle,
    bgColor: bgColor
  })) : null;
};

var _default = SimpleImageView;
exports.default = _default;
//# sourceMappingURL=SimpleImageView.js.map