import React from 'react';
import { Gesture, GestureDetector } from 'react-native-gesture-handler';
import { cancelAnimation, useAnimatedStyle, useSharedValue, withSpring } from 'react-native-reanimated';
import ViewGestureHandlerRootHOC from './ViewGestureHandlerRootHOC';

const SimpleImageView = _ref => {
  let {
    imageUri,
    bgColor
  } = _ref;
  const startX = useSharedValue(0);
  const transX = useSharedValue(0);
  const startY = useSharedValue(0);
  const transY = useSharedValue(0);
  const scaleXY = useSharedValue(1);
  const savedScale = useSharedValue(1);
  const rotation = useSharedValue(0);
  const savedRotation = useSharedValue(0);
  const transXYStyle = useAnimatedStyle(() => {
    return {
      transform: [{
        translateX: transX.value
      }, {
        translateY: transY.value
      }, {
        scale: scaleXY.value
      }, {
        rotateZ: `${rotation.value / Math.PI * 180}deg`
      }]
    };
  }, []);

  const scaleAnimation = () => {
    'worklet';

    cancelAnimation(scaleXY);
    cancelAnimation(startX);
    cancelAnimation(startY);
    savedScale.value = 1;
    startX.value = 0;
    startY.value = 0;
    scaleXY.value = withSpring(1);
    transX.value = withSpring(0);
    transY.value = withSpring(0);
    rotation.value = withSpring(0);
    savedRotation.value = 0;
  };

  const panHandler = Gesture.Pan().maxPointers(1).onStart(() => {
    transX.value = startX.value;
    transY.value = startY.value;
  }).onUpdate(event => {
    transX.value = event.translationX + startX.value;
    transY.value = event.translationY + startY.value;
  }).onEnd(() => {
    startX.value = transX.value;
    startY.value = transY.value;
  });
  const pinchHandler = Gesture.Pinch().onUpdate(e => {
    scaleXY.value = savedScale.value * (e.scale > 0 ? e.scale : 1);
  }).onEnd(() => {
    savedScale.value = scaleXY.value > 0 ? scaleXY.value : 1;
  });
  const tapHandler = Gesture.Tap().numberOfTaps(2).maxDelay(300).onEnd(scaleAnimation);
  const rotateHandler = Gesture.Rotation().onUpdate(e => {
    rotation.value = savedRotation.value + e.rotation;
  }).onEnd(() => {
    savedRotation.value = rotation.value;
  });
  const simultaneousHandler = Gesture.Simultaneous(panHandler, pinchHandler, tapHandler, rotateHandler);
  return imageUri !== null && imageUri !== void 0 && imageUri.uri ? /*#__PURE__*/React.createElement(GestureDetector, {
    gesture: simultaneousHandler
  }, /*#__PURE__*/React.createElement(ViewGestureHandlerRootHOC, {
    imageUri: imageUri,
    transXYStyle: transXYStyle,
    bgColor: bgColor
  })) : null;
};

export default SimpleImageView;
//# sourceMappingURL=SimpleImageView.js.map